@@ -4,16 +4,21 @@ import random
 import re
 import shutil
 import sys
+import tempfile
 import uuid
+import warnings
+from contextlib import contextmanager
 from datetime import datetime, timezone
+from distutils.dir_util import copy_tree
 from pathlib import Path
 from secrets import token_hex
 from time import sleep, time
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Iterator, Optional
 
 import pkg_resources
 from dvc.lock import LockError
 from dvc.repo import Repo as DVCRepo
+from git import InvalidGitRepositoryError, NoSuchPathError
 from git.repo import Repo as GITRepo
 
 from smartparams.utils.io import load_data, save_data
@@ -223,6 +228,24 @@ class SmartLab:
 
         path.with_suffix(path.suffix + '.dvc').unlink(missing_ok=True)
 
+    @staticmethod
+    def copy(
+        source: Path,
+        target: Path,
+    ) -> Path:
+        if source.is_dir():
+            copy_tree(str(source), str(target))
+            return target
+        return Path(shutil.copy2(source, target))
+
+    @contextmanager
+    def cache(
+        self,
+        path: Path,
+    ) -> Iterator[Path]:
+        with tempfile.TemporaryDirectory() as name:
+            yield self.copy(path, Path(name))
+
     def metadata(
         self,
         /,
@@ -284,7 +307,11 @@ class SmartLab:
 
     @staticmethod
     def _git_metadata() -> Dict[str, Any]:
-        repo = GITRepo(sys.argv[0], search_parent_directories=True)
+        try:
+            repo = GITRepo(sys.argv[0], search_parent_directories=True)
+        except (InvalidGitRepositoryError, NoSuchPathError):
+            warnings.warn("There is no GIT repo, use 'include_git=False'.")
+            return {}
         return dict(
             branch=repo.active_branch.name,
             commit=repo.active_branch.commit.hexsha if repo.active_branch.is_valid() else None,
