@@ -226,15 +226,23 @@ class Smart(Generic[T]):
         self,
         squash: bool = False,
         minimal: bool = False,
+        unpack: bool = False,
     ) -> Dict[str, Any]:
+        if unpack:
+            dictionary = dictutil.unpack_empty_keys(self._params)
+        else:
+            dictionary = self._params
+
         if squash or minimal:
-            dictionary = dict(self.items(flatten=True))
+            dictionary = dict(Smart(**dictionary).items(flatten=True))
             if minimal:
                 dictionary = dictutil.flatten_unique_keys(dictionary)
                 if not squash:
                     return dictutil.normalize(dictionary)
+
             return dictionary
-        return dictutil.normalize(self._params)
+
+        return dictutil.normalize(dictionary)
 
     def keys(
         self,
