@@ -1,5 +1,5 @@
 import json
-from typing import Any, Tuple
+from typing import Any, Optional, Tuple
 
 from smartparams.exceptions import ArgumentParserError
 
@@ -8,12 +8,12 @@ OBJECT_SEPARATOR = ':'
 PARAM_SEPARATOR = '='
 
 
-def join_keys(*args: str) -> str:
-    return KEY_SEPARATOR.join(a for a in args if a)
+def join_keys(*args: Optional[str]) -> str:
+    return KEY_SEPARATOR.join(a for a in args if a is not None)
 
 
-def join_objects(*args: str) -> str:
-    return OBJECT_SEPARATOR.join(a for a in args if a)
+def join_objects(*args: Optional[str]) -> str:
+    return OBJECT_SEPARATOR.join(a for a in args if a is not None)
 
 
 def parse_param(param: str) -> Tuple[str, Any]:
