@@ -66,12 +66,14 @@ class Iter:
         self,
         di: Dict,
         li: List,
+        li_o: List[str],
         tu: Tuple,
         se: Set,
         tu_d=(0, 1),
     ) -> None:
         self.di = di
         self.li = li
+        self.li_o = li_o
         self.tu = tu
         self.se = se
         self.tu_d = tu_d
