@@ -195,3 +195,25 @@ class TestRegisterCase(UnitCase):
             delay=0,
         )
         print_mock.assert_called()
+
+    @patch('smartparams.lab.sys', Mock(argv=['/', 'arg1', 'arg2']))
+    @patch('smartparams.lab.warnings')
+    def test_metadata__no_git(self, warnings: Mock) -> None:
+        metadata = self.lab.metadata(
+            include_date=False,
+            include_system=False,
+            include_dependencies=False,
+            user='user',
+        )
+
+        self.assertEqual({'user': 'user'}, metadata)
+        warnings.warn.assert_called_once()
+
+    def test_cache__file(self) -> None:
+        with self.lab.cache(Path(__file__)) as path:
+            self.assertTrue(path.exists())
+            self.assertTrue(len(path.read_text()))
+
+    def test_cache__directory(self) -> None:
+        with self.lab.cache(Path(__file__).parent) as path:
+            self.assertTrue(Path(__file__).name in [p.name for p in path.iterdir()])
