@@ -130,6 +130,15 @@ class TestSmartDictCase(UnitCase):
 
         self.assertEqual(expected, actual)
 
+    def test_dict__unpack(self) -> None:
+        expected = {'a': 10, 'b': 30, 'c': {'': 5, 'e': 12}, 'd': 40}
+        smart: Smart = Smart(a=10, b=20, c={'': 5, 'e': 12})
+        smart.set('', dict(b=30, d=40))
+
+        actual = smart.dict(unpack=True)
+
+        self.assertEqual(expected, actual)
+
     def test_keys(self) -> None:
         keys = self.smart.keys()
 
