@@ -12,6 +12,7 @@ class TestParseArguments(UnitCase):
         )
         self.expected = Arguments(
             path=Path('/home/params.yaml'),
+            mode=None,
             dump=False,
             skip_defaults=False,
             merge_params=False,
@@ -42,12 +43,19 @@ class TestParseArguments(UnitCase):
     @patch('smartparams.utils.cli.sys')
     def test__mode(self, sys: Mock) -> None:
         sys.argv = 'script.py --mode env'.split()
-        self.expected.path = Path('/home/params.env.yaml')
+        self.expected.mode = 'env'
 
         actual = parse_arguments(self.parser)
 
         self.assertEqual(self.expected, actual)
 
+    @patch('smartparams.utils.cli.sys')
+    def test__mode__no_path(self, sys: Mock) -> None:
+        sys.argv = 'script.py --mode env'.split()
+        self.expected.mode = 'env'
+
+        self.assertRaises(SystemExit, parse_arguments, create_argument_parser())
+
     @patch('smartparams.utils.cli.sys')
     def test__dump(self, sys: Mock) -> None:
         sys.argv = 'script.py --dump -sm'.split()
